@@ -546,6 +546,20 @@ protected:
      */
     void setItemTransactionMode(ItemSync::TransactionMode mode);
 
+    /**
+     * Set merge mode for item sync'ing.
+     *
+     * Default merge mode is RIDMerge.
+     *
+     * @note This method must be called before first call to itemRetrieved(),
+     * itemsRetrieved() or itemsRetrievedIncremental().
+     *
+     * @param mode Item merging mode (see ItemCreateJob for details on item merging)
+     * @see Akonadi::ItemSync::MergeMode
+     * @ince 4.14.11
+     */
+    void setItemMergingMode(ItemSync::MergeMode mode);
+
     /**
      * Set the fetch scope applied for item synchronization.
      * By default, the one set on the changeRecorder() is used. However, it can make sense
